BrainFrame Python API
=====================

The BrainFrame Python API is a wrapper around the BrainFrame server's REST API,
making it easier for Python users to build software that uses BrainFrame as a
video streaming and analysis platform. The data structures and methods
available in this library correspond closely with what's described in the
`REST API Documentation`_.

The documentation is split into categories, each of which have descriptions for
data structures and methods. Some example code is also provided.

The BrainFrame Python API is used by the BrainFrame Client and as a result is
tested heavily internally before release.

.. toctree::
   :maxdepth: 2

   api_class
   streams
   zones
   alarms
   analysis_results
   identities
   capsules
   premises
   storage
   users
   licenses
   exceptions
   sorting

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _`REST API Documentation`:
   https://aotu.ai/docs/api/
